#include "IZ_app.h"

IZ_ProcedureResult IZ_InitializeApp(IZ_App* app) {
	if (SDL_Init(
		SDL_INIT_VIDEO
		| SDL_INIT_GAMECONTROLLER
		| SDL_INIT_EVENTS
	) < 0) {
		fprintf_s(stderr, "SDL could not initialize! SDL_Error: %s\n", SDL_GetError());
		return 1;
	}

	char config_path[128];
	IZ_GetConfigPath(config_path, 128);

	IZ_LoadVideoConfig(config_path, &app->video_config);
	if (IZ_SaveVideoConfig(config_path, &app->video_config)) {
		fprintf_s(stderr, "Error committing video config.\n");
	}
	app->video_update_at = 0u;

	if (IZ_InitializeVideo(&app->video_config, &app->window, &app->screen_surface)) {
		return 2;
	}

	for (uint8_t p = 0; p < PLAYERS; p += 1) {
		IZ_LoadKeyboardConfig(config_path, &app->keyboard_state->config, p);
		if (IZ_SaveKeyboardConfig(config_path, &app->keyboard_state->config, p)) {
			fprintf_s(stderr, "Error committing keyboard config for player %d.\n", p);
		}

		IZ_LoadJoystickConfig(config_path, &app->joystick_state->config, p);
		if (IZ_SaveJoystickConfig(config_path, &app->joystick_state->config, p)) {
			fprintf_s(stderr, "Error committing joystick config for player %d.\n", p);
		}

		app->actions[p] = 0;
	}

	return 0;
}
